<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.1/1829459
 */

namespace Application\I18n;

class TranslatorFactory
{

    public static function buildTranslator($services)
    {
        $config        = $services->get('config');
        $config        = isset($config['translator']) ? $config['translator'] : array();
        $translator    = Translator::factory($config);
        $mvcTranslator = new \Zend\Mvc\I18n\Translator($translator);

        $translator->setEscaper(new \Application\Escaper\Escaper);

        // add event listener for context fallback on missing translations
        $translator->enableEventManager();
        $translator->getEventManager()->attach(
            $translator::EVENT_MISSING_TRANSLATION,
            array($translator, 'handleMissingTranslation')
        );

        // establish default locale settings
        $translator->setLocale($translator->getLocale() ?: 'en_US');
        $translator->setFallbackLocale($translator->getFallbackLocale() ?: 'en_US');

        // try to guess locale from browser language header (using intl if available)
        if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])
            && (!isset($config['detect_locale']) || $config['detect_locale'] !== false)
        ) {
            $locale = extension_loaded('intl')
                ? \Locale::acceptFromHttp($_SERVER['HTTP_ACCEPT_LANGUAGE'])
                : str_replace('-', '_', current(explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE'])));

            // if we can't find an exact match, venture a guess based on language prefix
            if (!$translator->isSupportedLocale($locale)) {
                $language = current(preg_split('/[^a-z]/i', $locale));
                $locale   = $translator->isSupportedLanguage($language) ?: $locale;
            }

            $translator->setLocale(strlen($locale) ? $locale : $translator->getLocale());
        }

        return $mvcTranslator;
    }
}
