<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.1/1829459
 */

namespace Users\Listener;

use Events\Listener\AbstractEventListener;
use Zend\EventManager\Event;

class UserEventListener extends AbstractEventListener
{
    public function onUser(Event $event)
    {
        $this->services->get('logger')->trace(self::class." Starting on user");
        // invalidate user cache on user form-commits and deletes
        $p4Admin = $this->services->get('p4_admin');

        // ignore git-fusion-reviews-* users - these are regularly updated
        // and used internally by git-fusion in ways that don't concern us
        if (strpos($event->getParam('id'), 'git-fusion-reviews-') === 0) {
            $this->services->get('logger')->trace(self::class." Ignoring git-fusion-review users");
            return;
        }

        try {
            $cache = $p4Admin->getService('cache');
            $this->services->get('logger')->trace(self::class." Found some cache for users");
            $cache->invalidateItem('users');
            $this->services->get('logger')->trace(self::class." Invalidating the Users Cache");
        } catch (\Exception $e) {
            $this->services->get('logger')->err($e);
        }
    }
}
